django-custom-mixins
====================

List custom mixins for projects

=======
Install
=======

.. code-block:: bash

    pip install django-custom-mixins


Mixins:

-  AjaxOnlyViewMixin
-  NeverCacheMixin
-  LoginRequiredMixin
-  CSRFExemptMixin
-  CacheMixin
-  CacheControlMixin
